Index: content/public/common/content_switches.cc |
diff --git a/content/public/common/content_switches.cc b/content/public/common/content_switches.cc |
index 7f1fc3615170644923ad1ab38a83acf08a46779e..454ae24a93ce93bac5c515e87f996406cf104ddd 100644 |
--- a/content/public/common/content_switches.cc |
+++ b/content/public/common/content_switches.cc |
@@ -330,9 +330,9 @@ const char kEnableDownloadResumption[] = "enable-download-resumption"; |
const char kEnableEncodedScreenCapture[] = "enable-encoded-screen-capture"; |
#endif |
-// Enables WebKit features that are in development. |
-const char kEnableExperimentalWebKitFeatures[] = |
- "enable-experimental-webkit-features"; |
+// Enables Web Platform features that are in development. |
+const char kEnableExperimentalWebPlatformFeatures[] = |
+ "enable-experimental-web-platform-features"; |
// Enables the CSS multicol implementation that uses the regions implementation. |
const char kEnableRegionBasedColumns[] = |